@@ -6,8 +6,4 @@ from .exceptions import SplitLunchError
 from .lunchmoney_splitwise import SplitLunch
 from .models import SplitLunchExpense
 
-__all__ = [
-    "SplitLunch",
-    "SplitLunchError",
-    "SplitLunchExpense"
-]
+__all__ = ["SplitLunch", "SplitLunchError", "SplitLunchExpense"]
